/// <reference types="react" />

import type { Button } from '@fluentui/react-components';
import type { ComponentProps } from '@fluentui/react-components';
import type { ComponentState } from '@fluentui/react-components';
import type { Context } from '@fluentui/react-context-selector';
import type { ContextSelector } from '@fluentui/react-context-selector';
import type { CopilotMode } from '@fluentui-copilot/react-provider';
import type { DesignVersion } from '@fluentui-copilot/react-provider';
import { FC } from 'react';
import type { ForwardRefComponent } from '@fluentui/react-components';
import type { PreviewHeaderProps } from '@fluentui-copilot/react-preview';
import type { PreviewMetadataProps } from '@fluentui-copilot/react-preview';
import type { PreviewProps } from '@fluentui-copilot/react-preview';
import type { PreviewSurfaceProps } from '@fluentui-copilot/react-preview';
import { Provider } from 'react';
import { ProviderProps } from 'react';
import * as React_2 from 'react';
import type { SensitivityLabelProps } from '@fluentui-copilot/react-sensitivity-label';
import type { Slot } from '@fluentui/react-components';
import type { SlotClassNames } from '@fluentui/react-components';

export declare const Citation: ForwardRefComponent<CitationProps>;

export declare const citationClassNames: SlotClassNames<CitationSlots>;

/**
 * Citation Props
 */
export declare type CitationProps = ComponentProps<Partial<CitationSlots>> & DesignVersion & {
    /**
     * HREF to the associated `Reference`.
     */
    referenceHref?: string;
    /**
     * Whether the citation is a block citation and has no built in margins.
     * Citations are inline by default with margins to separate them from inline text.
     */
    block?: boolean;
};

export declare type CitationSlots = {
    /**
     * The root slot.
     */
    root: NonNullable<Slot<'a'>>;
};

/**
 * State used in rendering Citation
 */
export declare type CitationState = ComponentState<CitationSlots> & Required<Pick<CitationProps, 'block' | 'designVersion'>> & {
    isPopoverLocked: boolean;
};

/**
 * Function to generate a Citation - Reference pair with correctly wired props.
 * Both the Citation and the Reference act as trigger components to Previews that are also correctly wired by the function.
 * Props can either be passed in to the function or applied directly to the generated components in JSX.
 *
 * A `useReferenceCitationPreview` hook exists that calls this function and memoizes its return value based on the props.
 * You should use the hook when the props used to generate the Citation - Reference pair can change dynamically.
 * If they are static, or in case you wanted to generate multiple pairs within a cycle, you should call
 * `generateReferenceCitationPreview` directly.
 *
 * @returns A Citation - Reference pair with correctly wired props.
 */
export declare const generateReferenceCitationPreview: ReferenceCitationPreviewGenerator;

/**
 * A "packaged Citation". A packaged Citation is a `Citation` that is
 * pre-packaged with props set by the `useReferenceCitation` hook.
 */
export declare type PackagedCitation = React_2.FC<PackagedCitationProps>;

/**
 * Props for a "packaged Citation". A packaged Citation is a `Citation` that is
 * pre-packaged with props set by the `useReferenceCitation` hook.
 */
export declare type PackagedCitationProps = Omit<CitationProps, 'referenceHref'> & Partial<Pick<CitationProps, 'referenceHref'>>;

export declare type PackagedCitationV2 = React_2.FC<CitationProps>;

export declare type PackagedPreviewContentV2Props = Pick<PreviewMetadataProps, 'icon' | 'primaryText' | 'secondaryText' | 'tertiaryText'> & {
    content?: React_2.ReactNode;
};

/**
 * A "packaged Reference". A packaged Reference is a `Reference` that is
 * pre-packaged with props set by the `useReferenceCitation` hook.
 */
export declare type PackagedReference = React_2.FC<PackagedReferenceProps>;

/**
 * Props for a "packaged Reference". A packaged Reference is a `Reference` that is
 * pre-packaged with props set by the `useReferenceCitation` hook.
 */
export declare type PackagedReferenceProps = Omit<ReferenceProps, PartialReferenceProps> & Partial<Pick<ReferenceProps, PartialReferenceProps>>;

export declare type PackagedReferenceV2 = React_2.FC<ReferenceV2Props>;

declare type PartialReferenceProps = 'citationHref' | 'index' | 'referenceId';

/** deprecated Use ReferenceV2 component, hooks and types instead. */
export declare const Reference: ForwardRefComponent<ReferenceProps>;

/**
 * Data used to package a `Citation` and `Reference` together with
 * the `useReferenceCitation` hook.
 */
export declare type ReferenceCitationData = {
    index: number;
    referenceId?: string;
    citationId?: string;
    citationProps?: PackagedCitationProps;
    referenceProps?: PackagedReferenceProps;
    previewHeaderProps?: PreviewHeaderProps;
    previewProps?: PreviewProps;
    previewSurfaceProps?: PreviewSurfaceProps;
    sensitivityLabelProps?: SensitivityLabelProps;
};

export declare type ReferenceCitationPreviewGenerator = (props: ReferenceCitationPreviewGeneratorProps) => {
    Citation: PackagedCitationV2;
    Reference: PackagedReferenceV2;
};

export declare type ReferenceCitationPreviewGeneratorProps = {
    citationPreviewProps?: Omit<PreviewProps, 'children'> & Partial<Pick<PreviewProps, 'children'>>;
    citationPreviewSurfaceProps?: PreviewSurfaceProps;
    citationProps?: CitationProps;
    index: number;
    previewContentProps?: PackagedPreviewContentV2Props;
    previewHeaderProps?: PreviewHeaderProps;
    referencePreviewProps?: Omit<PreviewProps, 'children'> & Partial<Pick<PreviewProps, 'children'>>;
    referencePreviewSurfaceProps?: PreviewSurfaceProps;
    referenceProps?: ReferenceV2Props;
    sensitivityLabelProps?: SensitivityLabelProps;
};

/** deprecated Use ReferenceV2 component, hooks and types instead. */
export declare const referenceClassNames: SlotClassNames<ReferenceSlots>;

/** deprecated The ReferenceGroup pattern is deprecated and will be removed in a future release. */
export declare const ReferenceGroupToggle: ForwardRefComponent<ReferenceGroupToggleProps>;

export declare const referenceGroupToggleClassNames: SlotClassNames<ReferenceGroupToggleSlots>;

/**
 * ReferenceGroupToggle Props
 */
export declare type ReferenceGroupToggleProps = ComponentProps<ReferenceGroupToggleSlots> & CopilotMode & {
    isOpen?: boolean;
};

export declare type ReferenceGroupToggleSlots = {
    root: NonNullable<Slot<'button'>>;
    icon?: Slot<'span'>;
};

/**
 * State used in rendering ReferenceGroupToggle
 */
export declare type ReferenceGroupToggleState = ComponentState<ReferenceGroupToggleSlots> & Required<Pick<ReferenceGroupToggleProps, 'isOpen' | 'mode'>>;

/** deprecated Use ReferenceListV2 component, hooks and types instead. */
export declare const ReferenceList: ForwardRefComponent<ReferenceListProps>;

/** deprecated Use ReferenceListV2 component, hooks and types instead. */
export declare const referenceListClassNames: SlotClassNames<ReferenceListSlots>;

export declare const ReferenceListContext: Context<ReferenceListContextValue>;

export declare const ReferenceListContextProvider: Provider<ReferenceListContextValue> & FC<ProviderProps<ReferenceListContextValue>>;

/**
 * Context shared between ReferenceList and its children components
 */
export declare type ReferenceListContextValue = Pick<ReferenceListV2State, 'areReferencesExpanded' | 'maxVisibleReferences' | 'overflowButtonTriggeredViaKeyboard' | 'referenceListRef' | 'shouldUseOverflow' | 'totalReferencesCount'>;

/** deprecated Use ReferenceListV2 component, hooks and types instead. */
export declare type ReferenceListProps = ComponentProps<ReferenceListSlots>;

/** deprecated Use ReferenceListV2 component, hooks and types instead. */
export declare type ReferenceListSlots = {
    /**
     * The root slot.
     */
    root: Slot<'ol'>;
};

/** deprecated Use ReferenceListV2 component, hooks and types instead. */
export declare type ReferenceListState = ComponentState<ReferenceListSlots>;

export declare const ReferenceListV2: ForwardRefComponent<ReferenceListV2Props>;

export declare const referenceListV2ClassNames: SlotClassNames<ReferenceListV2Slots>;

export declare type ReferenceListV2ContextValues = {
    referenceList: ReferenceListContextValue;
};

export declare type ReferenceListV2Props = ComponentProps<Partial<ReferenceListV2Slots>> & {
    /**
     * The maximum number of references to display before the overflow button is shown even if there is
     * enough space available to show more.
     * If not set, the overflow functionality will be disabled.
     * If this value is less than `minVisibleReferences`, then `minVisibleReferences` will take precedence.
     * @default undefined
     */
    maxVisibleReferences?: number;
    /**
     * The minimum number of references to always show before overflowing.
     * If this value exceeds the number of references, the overflow functionality will be disabled.
     * If this value is greater than `maxVisibleReferences`, then this will take precedence.
     * @default undefined
     */
    minVisibleReferences?: number;
};

export declare type ReferenceListV2Slots = {
    /** The root of the component that contains the list of references. */
    root: NonNullable<Slot<'div'>>;
    /** The region that contains the references and is used for arrow navigation. */
    arrowableRegion: NonNullable<Slot<'div'>>;
    /** A space containing a button that expands the list of references. This slot is only rendered when the list of references is collapsed. */
    showMoreButton?: Slot<'span'>;
    /** A space containing a button that collapses the list of references. This slot is only rendered when the list of references is expanded. */
    showLessButton?: Slot<'span'>;
};

export declare type ReferenceListV2State = ComponentState<ReferenceListV2Slots> & Pick<ReferenceListV2Props, 'maxVisibleReferences' | 'minVisibleReferences'> & {
    areReferencesExpanded: boolean;
    overflowButtonTriggeredViaKeyboard: React.MutableRefObject<boolean>;
    referenceListRef: React.RefObject<HTMLDivElement>;
    shouldUseOverflow: boolean;
    totalReferencesCount: number;
};

export declare const ReferenceOverflowButton: ForwardRefComponent<ReferenceOverflowButtonProps>;

export declare const referenceOverflowButtonClassNames: SlotClassNames<ReferenceOverflowButtonSlots>;

/**
 * ReferenceOverflowButton Props
 */
export declare type ReferenceOverflowButtonProps = ComponentProps<ReferenceOverflowButtonSlots> & DesignVersion & {
    /**
     * The text that is displayed inside of the overflow button. This text is only displayed when `children` has not been passed to the component.
     * If a string is passed, that is what is rendered verbatim.
     * If a callback is passed, the callback is called with the number of items that are overflowing, and the result of the callback is rendered.
     */
    text?: string | ((overflowCount: number) => React.ReactNode);
};

export declare type ReferenceOverflowButtonSlots = {
    /** The root of the component that renders the overflow button. */
    root: Slot<'button'>;
};

/**
 * State used in rendering ReferenceOverflowButton
 */
export declare type ReferenceOverflowButtonState = ComponentState<ReferenceOverflowButtonSlots> & Pick<Required<ReferenceOverflowButtonProps>, 'designVersion'> & {
    id: string;
    shouldRenderOverflowButton: boolean;
};

/** deprecated Use ReferenceV2 component, hooks and types instead. */
export declare type ReferenceProps = ComponentProps<Partial<ReferenceSlots>> & CopilotMode & {
    /**
     * Numeric index associated with `Citation`.
     */
    index: number;
    /**
     * HREF back to the `Citation` this `Reference` is associated with.
     */
    citationHref?: string;
    /**
     * Unique ID associated with this `Reference`.
     */
    referenceId?: string;
    /**
     * Text snippet from the reference source.
     */
    excerpt?: string;
    /**
     * @deprecated Inline layout is the only one that is available, use `Preview` component instead for an equivalent to a `Reference` with a popover layout inside of a `Popover`.
     */
    layout?: 'inline' | 'popover';
};

/** deprecated Use ReferenceV2 component, hooks and types instead. */
export declare type ReferenceSlots = {
    /**
     * The root slot.
     */
    root: NonNullable<Slot<'div'>>;
    /**
     * Citation slot. Displays a `Citation`. Set the `null` to hide the citation.
     */
    citation: Slot<'div'>;
    /**
     * Media slot. Used to display Avatars, Icons, etc.
     */
    media: Slot<'div'>;
    /**
     * Actions slot.
     */
    actions: Slot<'div'>;
    /**
     * Label slot. Primary description of the reference.
     */
    label: NonNullable<Slot<'div'>>;
    /**
     * Sensitivity slot. Used to display a `SensitivityLabel`.
     */
    sensitivity: Slot<'span'>;
    /**
     * Metadata slot. Container for `primaryText`, `secondaryText`, `tertiaryText` and `icon`.
     */
    metadata: NonNullable<Slot<'div'>>;
    /**
     * Primary text slot. First displayed metadata text.
     */
    primaryText: Slot<'span'>;
    /**
     * Secondary text slot. Second displayed metadata text.
     */
    secondaryText: Slot<'span'>;
    /**
     * Tertiary text slot. Third displayed metadata text.
     */
    tertiaryText: Slot<'span'>;
    /**
     * Icon slot. Icon displayed in metadata area.
     */
    icon: Slot<'span'>;
    /**
     * Content slot.
     */
    content: NonNullable<Slot<'div'>>;
    /**
     * Details button slot. Used to expand/collapse the reference.
     */
    detailsButton: Slot<typeof Button>;
};

/** deprecated Use ReferenceV2 component, hooks and types instead. */
export declare type ReferenceState = ComponentState<ReferenceSlots> & Required<Pick<ReferenceProps, 'mode' | 'layout' | 'index'>> & {
    /**
     * State used to renderer the `Reference` in an expanded state.
     */
    isExpanded: boolean;
};

export declare const ReferenceV2: ForwardRefComponent<ReferenceV2Props>;

export declare const referenceV2ClassNames: SlotClassNames<ReferenceV2Slots>;

export declare const referenceV2ExtraClassNames: {
    graphicChild: string;
};

export declare type ReferenceV2Props = ComponentProps<Partial<ReferenceV2Slots>> & DesignVersion & {};

export declare type ReferenceV2Slots = {
    /** The root of the component that renders the reference as either a button or an anchor element. */
    root: NonNullable<Slot<'button', 'a'>>;
    /** The number of the citation this reference corresponds to. */
    citation?: Slot<'span'>;
    /** A divider that visually separates the citation from the content of the reference. */
    divider?: Slot<'span'>;
    /** A space containing the content of the reference, which goes into an ellipsis if it overflows. */
    content?: Slot<'span'>;
    /** A space within the content slot where a graphic such as an icon or an image can be displayed before the rest of the content. */
    graphic?: Slot<'span'>;
};

export declare type ReferenceV2State = ComponentState<ReferenceV2Slots> & Required<Pick<ReferenceV2Props, 'id' | 'designVersion'>> & Pick<ReferenceListV2State, 'shouldUseOverflow'>;

/**
 * Render the final JSX of Citation
 */
export declare const renderCitation_unstable: (state: CitationState) => JSX.Element;

/** deprecated Use ReferenceV2 component, hooks and types instead. */
export declare const renderReference_unstable: (state: ReferenceState) => JSX.Element;

/**
 * Render the final JSX of ReferenceGroupToggle
 */
export declare const renderReferenceGroupToggle_unstable: (state: ReferenceGroupToggleState) => JSX.Element;

/** deprecated Use ReferenceListV2 component, hooks and types instead. */
export declare const renderReferenceList_unstable: (state: ReferenceListState) => JSX.Element;

/**
 * Render the final JSX of ReferenceList
 */
export declare const renderReferenceListV2_unstable: (state: ReferenceListV2State, contextValues: ReferenceListV2ContextValues) => JSX.Element;

/**
 * Render the final JSX of ReferenceOverflowButton
 */
export declare const renderReferenceOverflowButton_unstable: (state: ReferenceOverflowButtonState) => JSX.Element | null;

export declare const renderReferenceV2_unstable: (state: ReferenceV2State) => JSX.Element;

/**
 * Create the state required to render Citation.
 *
 * The returned state can be modified with hooks such as useCitationStyles_unstable,
 * before being passed to renderCitation_unstable.
 *
 * @param props - props from this instance of Citation
 * @param ref - reference to root HTMLElement of Citation
 */
export declare const useCitation_unstable: (props: CitationProps, ref: React.Ref<HTMLAnchorElement>) => CitationState;

/**
 * Apply styling to the Citation slots based on the state
 */
export declare const useCitationStyles_unstable: (state: CitationState) => CitationState;

/**
 * Create the state required to render Reference.
 *
 * The returned state can be modified with hooks such as useReferenceStyles_unstable,
 * before being passed to renderReference_unstable.
 *
 * @param props - props from this instance of Reference
 * @param ref - reference to root HTMLElement of Reference
 *
 * deprecated Use ReferenceV2 component, hooks and types instead.
 */
export declare const useReference_unstable: (props: ReferenceProps, ref: React_2.Ref<HTMLDivElement>) => ReferenceState;

export declare type UseReferenceCitationPreview = (data: ReferenceCitationData) => {
    Citation: PackagedCitation;
    Reference: PackagedReference;
};

/**
 * Hook to package a `Citation` and `Reference` together in an
 * accessibly by default manner.
 *
 * When using citations and references, prefer using them via this
 * hook to ensure props are wired up correctly.
 */
export declare const useReferenceCitationPreview: UseReferenceCitationPreview;

export declare type UseReferenceCitationPreviewV2 = ReferenceCitationPreviewGenerator;

/**
 * Hook to generate a Citation - Reference pair with correctly wired props.
 * Both the Citation and the Reference act as trigger components to Previews that are also correctly wired by the hook.
 * Props can either be passed in to the hook or applied directly to the generated components in JSX.
 *
 * This hook internally calls the `generateReferenceCitationPreview` function and memoizes its return value based on the props.
 * You should only use this hook when the props used to generate the Citation - Reference pair can change dynamically.
 * If they are static, or in case you wanted to generate multiple pairs within a cycle, you should call
 * `generateReferenceCitationPreview` directly.
 *
 * @returns A Citation - Reference pair with correctly wired props.
 */
export declare const useReferenceCitationPreviewV2: UseReferenceCitationPreviewV2;

export declare type UseReferenceCitationPreviewV2Props = ReferenceCitationPreviewGeneratorProps;

export declare type UseReferenceGroup = (props: UseReferenceGroupProps) => {
    referenceGroupToggleProps: ReferenceGroupToggleProps;
    referenceListProps: ReferenceListProps;
};

/**
 * Hook to package a `ReferenceGroupToggle` and `ReferenceList` together and
 * maintain their `isOpen` state.
 *
 * When rendering a group of references, prefer to use this hook
 * hook to ensure state is maintained correctly
 */
export declare const useReferenceGroup: UseReferenceGroup;

export declare type UseReferenceGroupProps = {
    referenceListId?: string;
};

/**
 * Create the state required to render ReferenceGroupToggle.
 *
 * The returned state can be modified with hooks such as useReferenceGroupToggleStyles_unstable,
 * before being passed to renderReferenceGroupToggle_unstable.
 *
 * @param props - props from this instance of ReferenceGroupToggle
 * @param ref - reference to root HTMLElement of ReferenceGroupToggle
 */
export declare const useReferenceGroupToggle_unstable: (props: ReferenceGroupToggleProps, ref: React_2.Ref<HTMLButtonElement>) => ReferenceGroupToggleState;

/**
 * Apply styling to the ReferenceGroupToggle slots based on the state
 */
export declare const useReferenceGroupToggleStyles_unstable: (state: ReferenceGroupToggleState) => ReferenceGroupToggleState;

/**
 * Create the state required to render ReferenceList.
 *
 * The returned state can be modified with hooks such as useReferenceListStyles_unstable,
 * before being passed to renderReferenceList_unstable.
 *
 * @param props - props from this instance of ReferenceList
 * @param ref - reference to root HTMLElement of ReferenceList
 *
 * deprecated Use ReferenceListV2 component, hooks and types instead.
 */
export declare const useReferenceList_unstable: (props: ReferenceListProps, ref: React_2.Ref<HTMLOListElement>) => ReferenceListState;

export declare const useReferenceListContext_unstable: <T>(selector: ContextSelector<ReferenceListContextValue, T>) => T;

/**
 * Apply styling to the ReferenceList slots based on the state
 *
 * deprecated Use ReferenceListV2 component, hooks and types instead.
 */
export declare const useReferenceListStyles_unstable: (state: ReferenceListState) => ReferenceListState;

/**
 * Create the state required to render ReferenceList.
 *
 * The returned state can be modified with hooks such as useReferenceListStyles_unstable,
 * before being passed to renderReferenceList_unstable.
 *
 * @param props - props from this instance of ReferenceList
 * @param ref - reference to root HTMLElement of ReferenceList
 */
export declare const useReferenceListV2_unstable: (props: ReferenceListV2Props, ref: React_2.Ref<HTMLDivElement>) => ReferenceListV2State;

/**
 * Apply styling to the ReferenceList slots based on the state
 */
export declare const useReferenceListV2Styles_unstable: (state: ReferenceListV2State) => ReferenceListV2State;

/**
 * Create the state required to render ReferenceOverflowButton.
 *
 * The returned state can be modified with hooks such as useReferenceOverflowButtonStyles_unstable,
 * before being passed to renderReferenceOverflowButton_unstable.
 *
 * @param props - props from this instance of ReferenceOverflowButton
 * @param ref - reference to root HTMLElement of ReferenceOverflowButton
 */
export declare const useReferenceOverflowButton_unstable: (props: ReferenceOverflowButtonProps, ref: React_2.Ref<HTMLButtonElement>) => ReferenceOverflowButtonState;

/**
 * Apply styling to the ReferenceOverflowButton slots based on the state
 */
export declare const useReferenceOverflowButtonStyles_unstable: (state: ReferenceOverflowButtonState) => ReferenceOverflowButtonState;

/**
 * Apply styling to the Reference slots based on the state
 *
 * deprecated Use ReferenceV2 component, hooks and types instead.
 */
export declare const useReferenceStyles_unstable: (state: ReferenceState) => ReferenceState;

/**
 * Create the state required to render Reference.
 *
 * The returned state can be modified with hooks such as useReferenceStyles_unstable,
 * before being passed to renderReference_unstable.
 *
 * @param props - props from this instance of Reference
 * @param ref - reference to root HTMLElement of Reference
 */
export declare const useReferenceV2_unstable: (props: ReferenceV2Props, ref: React_2.Ref<HTMLButtonElement | HTMLAnchorElement>) => ReferenceV2State;

/**
 * Apply styling to the Reference slots based on the state
 */
export declare const useReferenceV2Styles_unstable: (state: ReferenceV2State) => ReferenceV2State;

export { }
