"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
Object.defineProperty(exports, "useReference_unstable", {
    enumerable: true,
    get: function() {
        return useReference_unstable;
    }
});
const _interop_require_wildcard = require("@swc/helpers/_/_interop_require_wildcard");
const _react = /*#__PURE__*/ _interop_require_wildcard._(require("react"));
const _reactcomponents = require("@fluentui/react-components");
const _reacticons = require("@fluentui/react-icons");
const _useReferenceStylesstyles = require("./useReferenceStyles.styles");
const _Citation = require("../Citation");
const _ReferenceGroupContext = require("../../contexts/ReferenceGroupContext");
const _reactprovider = require("@fluentui-copilot/react-provider");
const useReference_unstable = (props, ref)=>{
    const { index, referenceId, citationHref, excerpt, layout = 'inline' } = props;
    const mode = (0, _reactprovider.useCopilotMode)(props.mode);
    const labelId = (0, _reactcomponents.useId)();
    const mediaId = (0, _reactcomponents.useId)();
    const [isExpanded, setIsExpanded] = _react.useState(layout === 'popover' ? true : false);
    const setPopoverOpen = (0, _reactcomponents.usePopoverContext_unstable)((context)=>context.setOpen);
    const onExpandClick = (_e)=>{
        setIsExpanded(!isExpanded);
    };
    const label = _reactcomponents.slot.always(props.label, {
        defaultProps: {
            id: labelId
        },
        elementType: 'div'
    });
    const media = _reactcomponents.slot.optional(props.media, {
        defaultProps: {
            id: mediaId
        },
        elementType: 'div'
    });
    if (media && /*#__PURE__*/ _react.isValidElement(media.children)) {
        media.children = /*#__PURE__*/ _react.cloneElement(media.children, {
            className: (0, _reactcomponents.mergeClasses)(media.children.props.className, _useReferenceStylesstyles.referenceExtraClassNames.mediaChild)
        });
    }
    if (media === null || media === void 0 ? void 0 : media.id) {
        var _label_ariadescribedby;
        var _label_ariadescribedby_concat;
        label['aria-describedby'] = (_label_ariadescribedby_concat = (_label_ariadescribedby = label['aria-describedby']) === null || _label_ariadescribedby === void 0 ? void 0 : _label_ariadescribedby.concat(media.id)) !== null && _label_ariadescribedby_concat !== void 0 ? _label_ariadescribedby_concat : media.id;
    }
    const ariaLabelledByProp = props['aria-labelledby'];
    const groupSemantics = _react.useMemo(()=>{
        return layout === 'inline' ? {
            role: 'group',
            'aria-labelledby': `${ariaLabelledByProp !== null && ariaLabelledByProp !== void 0 ? ariaLabelledByProp : ''} ${label.id}`,
            tabIndex: -1
        } : {};
    }, [
        layout,
        ariaLabelledByProp,
        label.id
    ]);
    // Within a popup, a citation should function as a close button
    const citationProps = _react.useMemo(()=>{
        const onPopoverCloseClick = (e)=>{
            setPopoverOpen(e, false);
            // don't navigate
            e.preventDefault();
        };
        return layout === 'popover' ? {
            referenceHref: '#',
            tabIndex: -1,
            'aria-label': `Close Reference ${index}`,
            onClick: onPopoverCloseClick
        } : {
            referenceHref: citationHref
        };
    }, [
        layout,
        citationHref,
        index,
        setPopoverOpen
    ]);
    const state = {
        isExpanded,
        mode: layout === 'popover' ? 'sidecar' : mode,
        layout,
        index,
        components: {
            root: 'div',
            citation: 'div',
            media: 'div',
            actions: 'div',
            label: 'div',
            sensitivity: 'span',
            metadata: 'div',
            content: 'div',
            primaryText: 'span',
            secondaryText: 'span',
            tertiaryText: 'span',
            icon: 'span',
            detailsButton: _reactcomponents.Button
        },
        root: _reactcomponents.slot.always((0, _reactcomponents.getIntrinsicElementProps)('div', {
            ref,
            id: referenceId,
            ...groupSemantics,
            ...props
        }), {
            elementType: 'div'
        }),
        citation: _reactcomponents.slot.optional(props.citation, {
            defaultProps: {
                children: /*#__PURE__*/ _react.createElement(_Citation.Citation, {
                    block: true,
                    ...citationProps
                }, index)
            },
            renderByDefault: true,
            elementType: 'div'
        }),
        media,
        actions: _reactcomponents.slot.optional(layout === 'inline' ? props.actions : null, {
            renderByDefault: true,
            elementType: 'div'
        }),
        label,
        sensitivity: _reactcomponents.slot.optional(props.sensitivity, {
            elementType: 'span'
        }),
        metadata: _reactcomponents.slot.always(props.metadata, {
            elementType: 'div'
        }),
        primaryText: _reactcomponents.slot.optional(props.primaryText, {
            defaultProps: {
                hidden: !isExpanded
            },
            elementType: 'span'
        }),
        secondaryText: _reactcomponents.slot.optional(props.secondaryText, {
            defaultProps: {
                hidden: !isExpanded
            },
            elementType: 'span'
        }),
        tertiaryText: _reactcomponents.slot.optional(props.tertiaryText, {
            defaultProps: {
                hidden: !isExpanded
            },
            elementType: 'span'
        }),
        icon: _reactcomponents.slot.optional(props.icon, {
            elementType: 'span'
        }),
        content: _reactcomponents.slot.always(props.content, {
            defaultProps: {
                children: excerpt && /*#__PURE__*/ _react.createElement(_reactcomponents.Caption1, null, excerpt)
            },
            elementType: 'div'
        }),
        detailsButton: _reactcomponents.slot.optional(layout === 'inline' ? props.detailsButton : null, {
            defaultProps: {
                appearance: 'transparent',
                'aria-expanded': isExpanded,
                'aria-label': 'show details',
                size: mode === 'sidecar' ? 'small' : 'medium',
                icon: {
                    children: getIcon(isExpanded, mode)
                }
            },
            renderByDefault: true,
            elementType: _reactcomponents.Button
        })
    };
    if (state.detailsButton) {
        const onClick = state.detailsButton.onClick;
        state.detailsButton.onClick = (0, _reactcomponents.mergeCallbacks)(onClick, onExpandClick);
    }
    const referenceGroupSetOpen = (0, _ReferenceGroupContext.useReferenceGroupSetOpen)();
    const onTargettedByCitation = (e)=>{
        var _e_relatedTarget;
        const relatedTargetHash = (_e_relatedTarget = e.relatedTarget) === null || _e_relatedTarget === void 0 ? void 0 : _e_relatedTarget.hash;
        if (relatedTargetHash && relatedTargetHash.substring(1) === referenceId) {
            referenceGroupSetOpen();
            setIsExpanded(true);
        }
    };
    state.root.onFocus = (0, _reactcomponents.mergeCallbacks)(state.root.onFocus, onTargettedByCitation);
    return state;
};
const getIcon = (isExpanded, mode)=>{
    if (mode === 'sidecar') {
        return !isExpanded ? /*#__PURE__*/ _react.createElement(_reacticons.ChevronDown16Regular, null) : /*#__PURE__*/ _react.createElement(_reacticons.ChevronUp16Regular, null);
    }
    return !isExpanded ? /*#__PURE__*/ _react.createElement(_reacticons.ChevronDown24Regular, null) : /*#__PURE__*/ _react.createElement(_reacticons.ChevronUp24Regular, null);
}; //# sourceMappingURL=useReference.js.map
