"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
Object.defineProperty(exports, "useReferenceList_unstable", {
    enumerable: true,
    get: function() {
        return useReferenceList_unstable;
    }
});
const _interop_require_wildcard = require("@swc/helpers/_/_interop_require_wildcard");
const _react = /*#__PURE__*/ _interop_require_wildcard._(require("react"));
const _reactcomponents = require("@fluentui/react-components");
const _reactutilities = require("@fluentui-copilot/react-utilities");
const _useReferenceStylesstyles = require("../Reference/useReferenceStyles.styles");
const useReferenceList_unstable = (props, ref)=>{
    const { arrowableRegion, children, maxVisibleReferences, minVisibleReferences, showLessButton, showMoreButton, ...rest } = props;
    const [areReferencesExpanded, setAreReferencesExpanded] = _react.useState(false);
    const referenceListRef = _react.useRef(null);
    const totalReferencesCount = _react.Children.count(children);
    const styles = (0, _useReferenceStylesstyles.useRootStyles)();
    const resolvedChildren = (0, _reactutilities.useOverflowMaxVisibleItems)({
        additionalCondition: !areReferencesExpanded,
        children,
        maxVisibleItems: maxVisibleReferences,
        minVisibleItems: minVisibleReferences,
        overflowClassName: styles.overflow
    });
    // We keep track of whether we are interacting with the overflow button via keyboard or not.
    const overflowButtonTriggeredViaKeyboard = _react.useRef(false);
    const focusAttributes = (0, _reactcomponents.useArrowNavigationGroup)({
        axis: 'both',
        circular: true,
        memorizeCurrent: true
    });
    const onShowMoreButtonClick = _react.useCallback(()=>{
        setAreReferencesExpanded(true);
    }, []);
    const onShowLessButtonClick = _react.useCallback(()=>{
        setAreReferencesExpanded(false);
    }, []);
    const shouldUseOverflow = (minVisibleReferences === undefined || minVisibleReferences < totalReferencesCount) && maxVisibleReferences !== undefined && !areReferencesExpanded;
    // Since the overflow button is an OverflowItem that's always visible, we need to account for it.
    const minVisibleOverflowItems = minVisibleReferences ? minVisibleReferences + 1 : 1;
    const state = {
        areReferencesExpanded,
        overflowButtonTriggeredViaKeyboard,
        maxVisibleReferences,
        minVisibleReferences: minVisibleOverflowItems,
        referenceListRef,
        shouldUseOverflow,
        totalReferencesCount,
        components: {
            root: 'div',
            arrowableRegion: 'div',
            showMoreButton: 'span',
            showLessButton: 'span'
        },
        root: _reactcomponents.slot.always((0, _reactcomponents.getIntrinsicElementProps)('div', {
            ref: (0, _reactcomponents.useMergedRefs)(ref, referenceListRef),
            ...rest
        }), {
            elementType: 'div'
        }),
        arrowableRegion: _reactcomponents.slot.always(arrowableRegion, {
            defaultProps: {
                ...focusAttributes,
                children: resolvedChildren
            },
            elementType: 'div'
        }),
        showMoreButton: shouldUseOverflow ? _reactcomponents.slot.optional(showMoreButton, {
            elementType: 'span'
        }) : undefined,
        showLessButton: areReferencesExpanded ? _reactcomponents.slot.optional(showLessButton, {
            elementType: 'span'
        }) : undefined
    };
    if (state.showMoreButton) {
        state.showMoreButton.onClick = (0, _reactcomponents.mergeCallbacks)(onShowMoreButtonClick, state.showMoreButton.onClick);
    }
    if (state.showLessButton) {
        state.showLessButton.onClick = (0, _reactcomponents.mergeCallbacks)(onShowLessButtonClick, state.showLessButton.onClick);
    }
    return state;
}; //# sourceMappingURL=useReferenceList.js.map
