"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
Object.defineProperty(exports, "generateReferenceCitationPreview", {
    enumerable: true,
    get: function() {
        return generateReferenceCitationPreview;
    }
});
const _interop_require_wildcard = require("@swc/helpers/_/_interop_require_wildcard");
const _react = /*#__PURE__*/ _interop_require_wildcard._(require("react"));
const _reactcomponents = require("@fluentui/react-components");
const _reactpreview = require("@fluentui-copilot/react-preview");
const _reactsensitivitylabel = require("@fluentui-copilot/react-sensitivity-label");
const _Citation = require("../../Citation");
const _ReferenceV2 = require("../../ReferenceV2");
// Abstract the citation that serves as the close button of the Preview into its own component so that we have access to the popover context.
const CitationCloseButton = (citationCloseButtonProps)=>{
    const setPopoverOpen = (0, _reactcomponents.usePopoverContext_unstable)((context)=>context.setOpen);
    const onPopoverCloseClick = _react.useCallback((ev)=>{
        setPopoverOpen(ev, false);
        // Don't navigate
        ev.preventDefault();
    }, [
        setPopoverOpen
    ]);
    const onCitationCloseButtonClick = (0, _reactcomponents.mergeCallbacks)(onPopoverCloseClick, citationCloseButtonProps.onClick);
    return /*#__PURE__*/ _react.createElement(_Citation.Citation, {
        ...citationCloseButtonProps,
        onClick: onCitationCloseButtonClick
    });
};
const generateReferenceCitationPreview = (props)=>{
    const { citationPreviewProps, citationPreviewSurfaceProps, citationProps, index, previewContentProps, previewHeaderProps, referencePreviewProps, referencePreviewSurfaceProps, referenceProps, sensitivityLabelProps } = props;
    const CitationWithPreview = (props)=>{
        var _previewContentProps_content;
        return /*#__PURE__*/ _react.createElement(_reactpreview.Preview, {
            closeOnScroll: true,
            positioning: "above",
            size: "small",
            trapFocus: true,
            withArrow: true,
            ...citationPreviewProps
        }, /*#__PURE__*/ _react.createElement(_reactpreview.PreviewTrigger, null, /*#__PURE__*/ _react.createElement(_Citation.Citation, {
            ...citationProps,
            ...props
        }, index)), /*#__PURE__*/ _react.createElement(_reactpreview.PreviewSurface, citationPreviewSurfaceProps, /*#__PURE__*/ _react.createElement(_reactpreview.PreviewContent, null, /*#__PURE__*/ _react.createElement(_reactpreview.PreviewHeader, {
            citation: /*#__PURE__*/ _react.createElement(CitationCloseButton, {
                "aria-label": `Close Reference ${index}`,
                referenceHref: "#",
                tabIndex: -1
            }, index),
            media: referenceProps === null || referenceProps === void 0 ? void 0 : referenceProps.graphic
        }, referenceProps === null || referenceProps === void 0 ? void 0 : referenceProps.children), /*#__PURE__*/ _react.createElement(_reactpreview.PreviewMetadata, {
            icon: previewContentProps === null || previewContentProps === void 0 ? void 0 : previewContentProps.icon,
            primaryText: previewContentProps === null || previewContentProps === void 0 ? void 0 : previewContentProps.primaryText,
            secondaryText: previewContentProps === null || previewContentProps === void 0 ? void 0 : previewContentProps.secondaryText,
            tertiaryText: previewContentProps === null || previewContentProps === void 0 ? void 0 : previewContentProps.tertiaryText
        }), sensitivityLabelProps && /*#__PURE__*/ _react.createElement(_reactsensitivitylabel.SensitivityLabel, sensitivityLabelProps), (_previewContentProps_content = previewContentProps === null || previewContentProps === void 0 ? void 0 : previewContentProps.content) !== null && _previewContentProps_content !== void 0 ? _previewContentProps_content : citationPreviewProps === null || citationPreviewProps === void 0 ? void 0 : citationPreviewProps.children)));
    };
    const ReferenceWithPreview = (props)=>{
        const mergedReferenceProps = {
            citation: index,
            ...referenceProps,
            ...props
        };
        var _previewHeaderProps_children, _previewContentProps_content;
        return /*#__PURE__*/ _react.createElement(_reactpreview.Preview, {
            closeOnScroll: true,
            positioning: "above",
            size: "small",
            trapFocus: true,
            withArrow: true,
            ...referencePreviewProps
        }, /*#__PURE__*/ _react.createElement(_reactpreview.PreviewTrigger, null, /*#__PURE__*/ _react.createElement(_ReferenceV2.Reference, mergedReferenceProps)), /*#__PURE__*/ _react.createElement(_reactpreview.PreviewSurface, referencePreviewSurfaceProps, /*#__PURE__*/ _react.createElement(_reactpreview.PreviewContent, null, /*#__PURE__*/ _react.createElement(_reactpreview.PreviewHeader, {
            citation: /*#__PURE__*/ _react.createElement(CitationCloseButton, {
                "aria-label": `Close Reference ${index}`,
                referenceHref: "#",
                tabIndex: -1
            }, index),
            media: referenceProps === null || referenceProps === void 0 ? void 0 : referenceProps.graphic,
            ...previewHeaderProps
        }, (_previewHeaderProps_children = previewHeaderProps === null || previewHeaderProps === void 0 ? void 0 : previewHeaderProps.children) !== null && _previewHeaderProps_children !== void 0 ? _previewHeaderProps_children : referenceProps === null || referenceProps === void 0 ? void 0 : referenceProps.children), /*#__PURE__*/ _react.createElement(_reactpreview.PreviewMetadata, {
            icon: previewContentProps === null || previewContentProps === void 0 ? void 0 : previewContentProps.icon,
            primaryText: previewContentProps === null || previewContentProps === void 0 ? void 0 : previewContentProps.primaryText,
            secondaryText: previewContentProps === null || previewContentProps === void 0 ? void 0 : previewContentProps.secondaryText,
            tertiaryText: previewContentProps === null || previewContentProps === void 0 ? void 0 : previewContentProps.tertiaryText
        }), sensitivityLabelProps && /*#__PURE__*/ _react.createElement(_reactsensitivitylabel.SensitivityLabel, sensitivityLabelProps), (_previewContentProps_content = previewContentProps === null || previewContentProps === void 0 ? void 0 : previewContentProps.content) !== null && _previewContentProps_content !== void 0 ? _previewContentProps_content : referencePreviewProps === null || referencePreviewProps === void 0 ? void 0 : referencePreviewProps.children)));
    };
    const components = {
        Citation: CitationWithPreview,
        Reference: ReferenceWithPreview
    };
    return components;
}; //# sourceMappingURL=generateReferenceCitationPreview.js.map
