"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
Object.defineProperty(exports, "useReferenceCitationPreview", {
    enumerable: true,
    get: function() {
        return useReferenceCitationPreview;
    }
});
const _interop_require_wildcard = require("@swc/helpers/_/_interop_require_wildcard");
const _jsxruntime = require("@fluentui/react-jsx-runtime/jsx-runtime");
const _react = /*#__PURE__*/ _interop_require_wildcard._(require("react"));
const _reactcomponents = require("@fluentui/react-components");
const _reactpreview = require("@fluentui-copilot/react-preview");
const _reactsensitivitylabel = require("@fluentui-copilot/react-sensitivity-label");
const _Citation = require("../Citation");
const _Reference = require("../Reference");
// Abstract the citation that serves as the close button of the Preview into its own component so that we have access to the popover context.
const CitationCloseButton = (citationCloseButtonProps)=>{
    const setPopoverOpen = (0, _reactcomponents.usePopoverContext_unstable)((context)=>context.setOpen);
    const onPopoverCloseClick = _react.useCallback((ev)=>{
        setPopoverOpen(ev, false);
        // Don't navigate
        ev.preventDefault();
    }, [
        setPopoverOpen
    ]);
    const onCitationCloseButtonClick = (0, _reactcomponents.mergeCallbacks)(onPopoverCloseClick, citationCloseButtonProps.onClick);
    return /*#__PURE__*/ (0, _jsxruntime.jsx)(_Citation.Citation, {
        ...citationCloseButtonProps,
        onClick: onCitationCloseButtonClick
    });
};
const useReferenceCitationPreview = ({ index, referenceId: propsRefId, citationId: propsCiteId, citationProps, referenceProps, previewHeaderProps, previewProps, previewSurfaceProps, sensitivityLabelProps })=>{
    const refId = (0, _reactcomponents.useId)();
    const citeId = (0, _reactcomponents.useId)();
    const referenceId = propsRefId !== null && propsRefId !== void 0 ? propsRefId : refId;
    const citationId = propsCiteId !== null && propsCiteId !== void 0 ? propsCiteId : citeId;
    const components = _react.useMemo(()=>{
        const citationHref = `#${citationId}`;
        const PackagedReference = (props)=>{
            var _props_index, _ref;
            const referenceIndex = (_ref = (_props_index = props.index) !== null && _props_index !== void 0 ? _props_index : referenceProps === null || referenceProps === void 0 ? void 0 : referenceProps.index) !== null && _ref !== void 0 ? _ref : index;
            return /*#__PURE__*/ (0, _jsxruntime.jsx)(_Reference.Reference, {
                ...referenceProps,
                index: referenceIndex,
                referenceId: referenceId,
                citationHref: citationHref,
                ...props
            });
        };
        const CitationWithPreview = (props)=>{
            // We assert content as a slot to use it with its resolved props object and the correct defaults below.
            const content = _reactcomponents.slot.always(referenceProps ? referenceProps.content : undefined, {
                defaultProps: {
                    children: (referenceProps === null || referenceProps === void 0 ? void 0 : referenceProps.excerpt) && /*#__PURE__*/ (0, _jsxruntime.jsx)(_reactcomponents.Caption1, {
                        children: referenceProps.excerpt
                    })
                },
                elementType: 'div'
            });
            const citationWithPreviewState = {
                components: {
                    content: 'div'
                },
                content
            };
            (0, _reactcomponents.assertSlots)(citationWithPreviewState);
            // We resolve the slots' objects for sensitivity and title here so that we can use the information from their children below.
            const sensitivity = _reactcomponents.slot.optional(referenceProps === null || referenceProps === void 0 ? void 0 : referenceProps.sensitivity, {
                elementType: 'span'
            });
            const title = _reactcomponents.slot.optional(referenceProps === null || referenceProps === void 0 ? void 0 : referenceProps.label, {
                elementType: 'div'
            });
            var _previewHeaderProps_children, _sensitivityLabelProps_description, _previewSurfaceProps_children;
            return /*#__PURE__*/ (0, _jsxruntime.jsxs)(_reactpreview.Preview, {
                closeOnScroll: true,
                positioning: "above",
                size: "small",
                trapFocus: true,
                withArrow: true,
                ...previewProps,
                children: [
                    /*#__PURE__*/ (0, _jsxruntime.jsx)(_reactpreview.PreviewTrigger, {
                        children: /*#__PURE__*/ (0, _jsxruntime.jsx)(_Citation.Citation, {
                            ...citationProps,
                            id: citationId,
                            ...props,
                            children: index
                        })
                    }),
                    /*#__PURE__*/ (0, _jsxruntime.jsx)(_reactpreview.PreviewSurface, {
                        ...previewSurfaceProps,
                        children: /*#__PURE__*/ (0, _jsxruntime.jsxs)(_reactpreview.PreviewContent, {
                            children: [
                                /*#__PURE__*/ (0, _jsxruntime.jsx)(_reactpreview.PreviewHeader, {
                                    citation: /*#__PURE__*/ (0, _jsxruntime.jsx)(CitationCloseButton, {
                                        "aria-label": `Close Reference ${index}`,
                                        referenceHref: "#",
                                        tabIndex: -1,
                                        children: index
                                    }),
                                    media: referenceProps === null || referenceProps === void 0 ? void 0 : referenceProps.media,
                                    ...previewHeaderProps,
                                    children: (_previewHeaderProps_children = previewHeaderProps === null || previewHeaderProps === void 0 ? void 0 : previewHeaderProps.children) !== null && _previewHeaderProps_children !== void 0 ? _previewHeaderProps_children : title === null || title === void 0 ? void 0 : title.children
                                }),
                                /*#__PURE__*/ (0, _jsxruntime.jsx)(_reactpreview.PreviewMetadata, {
                                    icon: referenceProps === null || referenceProps === void 0 ? void 0 : referenceProps.icon,
                                    primaryText: referenceProps === null || referenceProps === void 0 ? void 0 : referenceProps.primaryText,
                                    secondaryText: referenceProps === null || referenceProps === void 0 ? void 0 : referenceProps.secondaryText,
                                    tertiaryText: referenceProps === null || referenceProps === void 0 ? void 0 : referenceProps.tertiaryText
                                }),
                                sensitivity && /*#__PURE__*/ (0, _jsxruntime.jsx)(_reactsensitivitylabel.SensitivityLabel, {
                                    description: (_sensitivityLabelProps_description = sensitivityLabelProps === null || sensitivityLabelProps === void 0 ? void 0 : sensitivityLabelProps.description) !== null && _sensitivityLabelProps_description !== void 0 ? _sensitivityLabelProps_description : '',
                                    children: sensitivity.children
                                }),
                                /*#__PURE__*/ (0, _jsxruntime.jsx)(citationWithPreviewState.content, {}),
                                (_previewSurfaceProps_children = previewSurfaceProps === null || previewSurfaceProps === void 0 ? void 0 : previewSurfaceProps.children) !== null && _previewSurfaceProps_children !== void 0 ? _previewSurfaceProps_children : previewProps === null || previewProps === void 0 ? void 0 : previewProps.children
                            ]
                        })
                    })
                ]
            });
        };
        return {
            Citation: CitationWithPreview,
            Reference: PackagedReference
        };
    }, [
        index,
        referenceId,
        citationId,
        referenceProps,
        citationProps,
        previewHeaderProps,
        previewProps,
        previewSurfaceProps,
        sensitivityLabelProps
    ]);
    return components;
}; //# sourceMappingURL=useReferenceCitationPreview.js.map
