import * as React from 'react';
import { getIntrinsicElementProps, slot } from '@fluentui/react-components';
import { ChevronDown16Regular, ChevronUp16Regular } from '@fluentui/react-icons';
import { useCopilotMode } from '@fluentui-copilot/react-provider';
/**
 * Create the state required to render ReferenceGroupToggle.
 *
 * The returned state can be modified with hooks such as useReferenceGroupToggleStyles_unstable,
 * before being passed to renderReferenceGroupToggle_unstable.
 *
 * @param props - props from this instance of ReferenceGroupToggle
 * @param ref - reference to root HTMLElement of ReferenceGroupToggle
 */
export const useReferenceGroupToggle_unstable = (props, ref) => {
  const {
    isOpen = false
  } = props;
  const mode = useCopilotMode(props.mode);
  return {
    mode,
    isOpen,
    components: {
      root: 'button',
      icon: 'span'
    },
    root: slot.always(getIntrinsicElementProps('button', {
      ref,
      'aria-expanded': isOpen,
      type: 'button',
      ...props
    }), {
      elementType: 'button'
    }),
    icon: slot.optional(props.icon, {
      defaultProps: {
        children: isOpen ? /*#__PURE__*/React.createElement(ChevronUp16Regular, null) : /*#__PURE__*/React.createElement(ChevronDown16Regular, null)
      },
      renderByDefault: true,
      elementType: 'span'
    })
  };
};
//# sourceMappingURL=useReferenceGroupToggle.js.map