import { jsx as _jsx, jsxs as _jsxs } from "@fluentui/react-jsx-runtime/jsx-runtime";
import * as React from 'react';
import { Caption1, assertSlots, mergeCallbacks, slot, useId, usePopoverContext_unstable } from '@fluentui/react-components';
import { Preview, PreviewContent, PreviewHeader, PreviewMetadata, PreviewSurface, PreviewTrigger } from '@fluentui-copilot/react-preview';
import { SensitivityLabel } from '@fluentui-copilot/react-sensitivity-label';
import { Citation } from '../Citation';
import { Reference } from '../Reference';
// Abstract the citation that serves as the close button of the Preview into its own component so that we have access to the popover context.
const CitationCloseButton = citationCloseButtonProps => {
  const setPopoverOpen = usePopoverContext_unstable(context => context.setOpen);
  const onPopoverCloseClick = React.useCallback(ev => {
    setPopoverOpen(ev, false);
    // Don't navigate
    ev.preventDefault();
  }, [setPopoverOpen]);
  const onCitationCloseButtonClick = mergeCallbacks(onPopoverCloseClick, citationCloseButtonProps.onClick);
  return /*#__PURE__*/_jsx(Citation, {
    ...citationCloseButtonProps,
    onClick: onCitationCloseButtonClick
  });
};
/**
 * Hook to package a `Citation` and `Reference` together in an
 * accessibly by default manner.
 *
 * When using citations and references, prefer using them via this
 * hook to ensure props are wired up correctly.
 */
export const useReferenceCitationPreview = ({
  index,
  referenceId: propsRefId,
  citationId: propsCiteId,
  citationProps,
  referenceProps,
  previewHeaderProps,
  previewProps,
  previewSurfaceProps,
  sensitivityLabelProps
}) => {
  const refId = useId();
  const citeId = useId();
  const referenceId = propsRefId !== null && propsRefId !== void 0 ? propsRefId : refId;
  const citationId = propsCiteId !== null && propsCiteId !== void 0 ? propsCiteId : citeId;
  const components = React.useMemo(() => {
    const citationHref = `#${citationId}`;
    const PackagedReference = props => {
      var _props_index, _ref;
      const referenceIndex = (_ref = (_props_index = props.index) !== null && _props_index !== void 0 ? _props_index : referenceProps === null || referenceProps === void 0 ? void 0 : referenceProps.index) !== null && _ref !== void 0 ? _ref : index;
      return /*#__PURE__*/_jsx(Reference, {
        ...referenceProps,
        index: referenceIndex,
        referenceId: referenceId,
        citationHref: citationHref,
        ...props
      });
    };
    const CitationWithPreview = props => {
      // We assert content as a slot to use it with its resolved props object and the correct defaults below.
      const content = slot.always(referenceProps ? referenceProps.content : undefined, {
        defaultProps: {
          children: (referenceProps === null || referenceProps === void 0 ? void 0 : referenceProps.excerpt) && /*#__PURE__*/_jsx(Caption1, {
            children: referenceProps.excerpt
          })
        },
        elementType: 'div'
      });
      const citationWithPreviewState = {
        components: {
          content: 'div'
        },
        content
      };
      assertSlots(citationWithPreviewState);
      // We resolve the slots' objects for sensitivity and title here so that we can use the information from their children below.
      const sensitivity = slot.optional(referenceProps === null || referenceProps === void 0 ? void 0 : referenceProps.sensitivity, {
        elementType: 'span'
      });
      const title = slot.optional(referenceProps === null || referenceProps === void 0 ? void 0 : referenceProps.label, {
        elementType: 'div'
      });
      var _previewHeaderProps_children, _sensitivityLabelProps_description, _previewSurfaceProps_children;
      return /*#__PURE__*/_jsxs(Preview, {
        closeOnScroll: true,
        positioning: "above",
        size: "small",
        trapFocus: true,
        withArrow: true,
        ...previewProps,
        children: [/*#__PURE__*/_jsx(PreviewTrigger, {
          children: /*#__PURE__*/_jsx(Citation, {
            ...citationProps,
            id: citationId,
            ...props,
            children: index
          })
        }), /*#__PURE__*/_jsx(PreviewSurface, {
          ...previewSurfaceProps,
          children: /*#__PURE__*/_jsxs(PreviewContent, {
            children: [/*#__PURE__*/_jsx(PreviewHeader, {
              citation: /*#__PURE__*/_jsx(CitationCloseButton, {
                "aria-label": `Close Reference ${index}`,
                referenceHref: "#",
                tabIndex: -1,
                children: index
              }),
              media: referenceProps === null || referenceProps === void 0 ? void 0 : referenceProps.media,
              ...previewHeaderProps,
              children: (_previewHeaderProps_children = previewHeaderProps === null || previewHeaderProps === void 0 ? void 0 : previewHeaderProps.children) !== null && _previewHeaderProps_children !== void 0 ? _previewHeaderProps_children : title === null || title === void 0 ? void 0 : title.children
            }), /*#__PURE__*/_jsx(PreviewMetadata, {
              icon: referenceProps === null || referenceProps === void 0 ? void 0 : referenceProps.icon,
              primaryText: referenceProps === null || referenceProps === void 0 ? void 0 : referenceProps.primaryText,
              secondaryText: referenceProps === null || referenceProps === void 0 ? void 0 : referenceProps.secondaryText,
              tertiaryText: referenceProps === null || referenceProps === void 0 ? void 0 : referenceProps.tertiaryText
            }), sensitivity && /*#__PURE__*/_jsx(SensitivityLabel, {
              description: (_sensitivityLabelProps_description = sensitivityLabelProps === null || sensitivityLabelProps === void 0 ? void 0 : sensitivityLabelProps.description) !== null && _sensitivityLabelProps_description !== void 0 ? _sensitivityLabelProps_description : '',
              children: sensitivity.children
            }), /*#__PURE__*/_jsx(citationWithPreviewState.content, {}), (_previewSurfaceProps_children = previewSurfaceProps === null || previewSurfaceProps === void 0 ? void 0 : previewSurfaceProps.children) !== null && _previewSurfaceProps_children !== void 0 ? _previewSurfaceProps_children : previewProps === null || previewProps === void 0 ? void 0 : previewProps.children]
          })
        })]
      });
    };
    return {
      Citation: CitationWithPreview,
      Reference: PackagedReference
    };
  }, [index, referenceId, citationId, referenceProps, citationProps, previewHeaderProps, previewProps, previewSurfaceProps, sensitivityLabelProps]);
  return components;
};
//# sourceMappingURL=useReferenceCitationPreview.js.map