import * as React from 'react';
import { __styles, useId } from '@fluentui/react-components';
const useStyles = __styles({
  hidden: {
    mc9l5x: "fjseox"
  }
}, {
  d: [".fjseox{display:none;}"]
});
/**
 * Hook to package a `ReferenceGroupToggle` and `ReferenceList` together and
 * maintain their `isOpen` state.
 *
 * When rendering a group of references, prefer to use this hook
 * hook to ensure state is maintained correctly
 */
export const useReferenceGroup = props => {
  const [isOpen, setIsOpen] = React.useState(false);
  const styles = useStyles();
  const referenceListId = useId('reference-list', props.referenceListId);
  return React.useMemo(() => {
    const handleClick = () => {
      setIsOpen(isOpen => !isOpen);
    };
    const referenceGroupToggleProps = {
      'aria-controls': referenceListId,
      isOpen,
      onClick: handleClick
    };
    const referenceListProps = {
      className: isOpen ? undefined : styles.hidden,
      id: referenceListId
    };
    return {
      referenceGroupToggleProps,
      referenceListProps
    };
  }, [isOpen, referenceListId, styles.hidden]);
};
//# sourceMappingURL=useReferenceGroup.js.map